package com.xlht.xlhtproject.service.impl;

import java.util.List;

import com.xlht.xlhtproject.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.xlht.xlhtproject.mapper.ZAssayResultMapper;
import com.xlht.xlhtproject.domain.ZAssayResult;
import com.xlht.xlhtproject.service.IZAssayResultService;

/**
 * 化验结果明细Service业务层处理
 * 
 * @author slibra
 * @date 2024-09-19
 */
@Service
public class ZAssayResultServiceImpl implements IZAssayResultService 
{
    @Autowired
    private ZAssayResultMapper zAssayResultMapper;

    /**
     * 查询化验结果明细
     * 
     * @param resultId 化验结果明细主键
     * @return 化验结果明细
     */
    @Override
    public ZAssayResult selectZAssayResultByResultId(Long resultId)
    {
        return zAssayResultMapper.selectZAssayResultByResultId(resultId);
    }

    /**
     * 查询化验结果明细列表
     * 
     * @param zAssayResult 化验结果明细
     * @return 化验结果明细
     */
    @Override
    public List<ZAssayResult> selectZAssayResultList(ZAssayResult zAssayResult)
    {
        return zAssayResultMapper.selectZAssayResultList(zAssayResult);
    }

    /**
     * 新增化验结果明细
     * 
     * @param zAssayResult 化验结果明细
     * @return 结果
     */
    @Override
    public int insertZAssayResult(ZAssayResult zAssayResult)
    {
        zAssayResult.setCreateTime(DateUtils.getNowDate());
        return zAssayResultMapper.insertZAssayResult(zAssayResult);
    }

    /**
     * 修改化验结果明细
     * 
     * @param zAssayResult 化验结果明细
     * @return 结果
     */
    @Override
    public int updateZAssayResult(ZAssayResult zAssayResult)
    {
        zAssayResult.setUpdateTime(DateUtils.getNowDate());
        return zAssayResultMapper.updateZAssayResult(zAssayResult);
    }

    /**
     * 批量删除化验结果明细
     * 
     * @param resultIds 需要删除的化验结果明细主键
     * @return 结果
     */
    @Override
    public int deleteZAssayResultByResultIds(Long[] resultIds)
    {
        return zAssayResultMapper.deleteZAssayResultByResultIds(resultIds);
    }

    /**
     * 删除化验结果明细信息
     * 
     * @param resultId 化验结果明细主键
     * @return 结果
     */
    @Override
    public int deleteZAssayResultByResultId(Long resultId)
    {
        return zAssayResultMapper.deleteZAssayResultByResultId(resultId);
    }
}
